@@ -26,33 +26,37 @@ Test2::Aggregate - Aggregate tests for increased speed
 
 =head1 VERSION
 
-Version 0.13
+Version 0.14
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 DESCRIPTION
 
 Aggregates all tests specified with C<dirs> (which can even be individual tests)
 to avoid forking, reloading etc that can help with performance (dramatically if
-you have numerous small tests) and also facilitate group profiling.
+you have numerous small tests) and also facilitate group profiling. It is quite
+common to have tests that take over a second of startup time for milliseconds of
+actual runtime - L<Test2::Aggregate> removes that overhead.
 Test files are expected to end in B<.t> and are run as subtests of a single
 aggregate test.
 
 A bit similar (mainly in intent) to L<Test::Aggregate>, but no inspiration was
 drawn from the specific module, so simpler in concept and execution, which
-makes it more likely to work with your test suite (especially if you use modern
-tools like Test2). It does not even try to package each test by default, which may
-be good or bad (e.g. redefines), depending on your requirements.
+makes it much more likely to work with your test suite (especially if you use modern
+tools like L<Test2::Suite>). It does not even try to package each test by default
+(there is an option), which may be good or bad, depending on your requirements.
 
 Generally, the way to use this module is to try to aggregate sets of quick tests
-(e.g. unit tests). Try to iterativelly add tests to the aggregator, dropping those
-that do not work. You can use plain text file lists for this. Trying an entire suite
-in one go is a bad idea, an incompatible test can break the run making the subsequent
-tests fail (especially when doing things like globally redefining built-ins etc).
-The module can work with L<Test::More> suites, but you will have less issues
-with L<Test2::Suite> (see notes).
+(e.g. unit tests). Try to iterativelly add tests to the aggregator, using the C<lists>
+option, so you can easily edit and remove those that do not work. Trying an entire,
+large, suite in one go is not a good idea, as an incompatible test can break the
+run making the subsequent tests fail (especially when doing things like globally
+redefining built-ins etc) - see the module usage notes for help.
+
+The module can work with L<Test::Builder> / L<Test::More> suites, but you will
+have less issues with L<Test2::Suite> (see notes).
 
 =head1 METHODS
  
@@ -464,13 +468,8 @@ the end of the test etc.
 
 Unit tests are usually great for aggregating. You could use the hash that C<run_tests>
 returns in a script that tries to add more tests automatically to an aggregate list
-to see which added tests passed and keep them, dropping failures. An example of
-how to print out the passing tests in the order they ran from the C<$stats> hashref
-that C<run_tests> returns:
-
- foreach (sort {$stats->{$a}->{test_no} <=> $stats->{$b}->{test_no}} keys %$stats) {
-     print $fh "$_\n" if $stats->{$_}->{pass_perc};
- }
+to see which added tests passed and keep them, dropping failures. See later in the
+notes for a detailed example.
 
 Trying to aggregate too many tests into a single one can be counter-intuitive as
 you would ideally want to parallelize your test suite (so a super-long aggregated
@@ -541,6 +540,71 @@ disable warnings on redefines only for tests that run aggregated:
 Another idea is to make the test die when it is run under the aggregator, if, at
 design time, you know it is not supposed to run aggregated.
 
+=head2 Example aggregating strategy
+
+There are many approaches you could do to use C<Test2::Aggregate> with an existing
+test suite, so for example you can start by making a list of the test files you
+are trying to aggregate:
+
+ find t -name '*.t' > all.lst
+
+If you have a substantial test suite, perhaps try with a portion of it (a subdir?)
+instead of the entire suite. In any case, try running them aggregated like this:
+
+ use Test2::Aggregate;
+ use Test2::V0; # Or Test::More;
+
+ my $stats = Test2::Aggregate::run_tests(
+    lists => ['all.lst'],
+ );
+
+ open OUT, ">pass.lst";
+ foreach my $test (sort {$stats->{$a}->{test_no} <=> $stats->{$b}->{test_no}} keys %$stats) {
+     print OUT "$test\n" if $stats->{$test}->{pass_perc};
+ }
+ close OUT;
+
+ done_testing();
+
+Run the above with C<prove> or C<yath> in verbose mode, so that in case the run
+hangs (it can happen), you can see where it did so and edit C<all.lst> removing
+the offending test.
+
+If the run completes, you have a "starting point" - i.e. a list that can run under
+the aggregator in C<pass.lst>.
+You can try adding back some of the failed tests - test failures can be cascading,
+so some might be passing if added back, or have small issues you can address.
+
+Try adding C<test_warnings =E<gt> 1> to C<run_tests> to fix warnings as well, unless
+it is common for your tests to have C<STDERR> output.
+
+To have your entire suite run aggregated tests together once and not repeat them
+along with the other, non-aggregated, tests, it is a good idea to use the
+C<--exclude-list> option of the C<Test2::Harness>.
+
+Hopefully your tests can run in parallel (C<prove/yath -j>), in which case you
+would split your aggregated tests into multiple lists to have them run in parallel.
+Here is an example of a wrapper around C<yath>, to easily handle multiple lists:
+
+ BEGIN {
+     my @args = ();
+     foreach (@ARGV) {
+         if (/--exclude-lists=(\S+)/) {
+             my $all = 't/aggregate/aggregated.tests';
+             `awk '{print "t/"\$0}' $1 > $all`;
+             push @args, "--exclude-list=$all";
+         } else { push @args, $_ if $_; }
+     }
+     push @args, qw(-P...) # Preload module list (useful for non-aggregated tests)
+         unless grep {/--cover/} @args;
+     @ARGV = @args;
+ }
+ exec ('yath', @ARGV);
+
+You would call it with something like C<--exclude-lists=t/aggregate/*.lst>, and
+the tests listed will be excluded (you will have them running aggregated through
+their own C<.t> files using L<Test2::Aggregate>).
+
 =head1 AUTHOR
 
 Dimitrios Kechagias, C<< <dkechag at cpan.org> >>
